@@ -1,6 +1,6 @@
 import os
 
-__DEFAULT_HOST__ = 'https://devapi.treeschema.com'
+__DEFAULT_HOST__ = 'https://api.treeschema.com'
 
 # API Endpoints for Tree Schema 
 
