@@ -1,4 +1,12 @@
 
+class DataAssetDoesNotExist(Exception):
+    def __init__(self, message):
+        super().__init__(message)
+
+class InvalidFieldInputs(Exception):
+    def __init__(self, message):
+        super().__init__(message)
+
 class InvalidInputs(Exception):
     def __init__(self, message):
         super().__init__(message)
@@ -11,7 +19,6 @@ class TreeSchemaApiError(Exception):
     def __init__(self, message):
         super().__init__(message)
 
-
 class UsernameSecretRequired(Exception):
     def __init__(self, message):
         super().__init__(message)
